/*
 *  IVCCLIB: Intel Video Capture Card Library
 *  by Jeff Norris, jnorris@alum.mit.edu
 *  
 *  File: grabber.h
 *
 *  Description: This file contains useful constants.  Note that the
 *  NUM_ROWS and NUM_COLS variables are VERY important- they
 *  determine what size of an image the grabbers will work with.
 *
 */

#ifndef __GRABBER_H__
#define __GRABBER_H__

/* Image constants */
#define NUM_ROWS 480
#define NUM_COLS 640
#define PIXELSIZE 4
#define IMAGESIZE NUM_ROWS*NUM_COLS*PIXELSIZE
#define FPS 30
#define NOFRAMES 1
#define MAXSIZE (NOFRAMES*PIXELSIZE*NUM_ROWS*NUM_COLS)
#define DEFAULT_FORMAT METEOR_FMT_NTSC

/* GRABBER ID'S */
#define GRABBER0 0
#define GRABBER1 1
#define GRABBER2 2
#define GRABBER3 3
#define GRABBER4 4
#define GRABBER5 5
#define GRABBER6 6

#endif
