/*
 *  IVCCLIB: Intel Video Capture Card Library
 *  by Jeff Norris, jnorris@alum.mit.edu
 *  
 *  File: m_ivccsetup.c
 *
 *  Description:  It's unlikely that a typical user will need to
 *  edit this file.  This file contains all of the functions needed
 *  to start an observer, and sets up the frame arrival signal.  
 *  Frame signals are actually first handled here, and then passed
 *  into the observer.  This file is compiled with m_observer.c to make
 *  m_observer.mexlx, which is then executed from Matlab.
 */

#ifndef __OBSERVER_H__
#define __OBSERVER_H__

/* function prototypes */
void observersetup();
void observershutdown();
void framesig(int);
void attachgrabber(int, void (int, char*));
void detachgrabber();
void break_handler(int);

int quit;
int   grabberid;

#endif



